<template>
    <div class="app-container">
      <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch" label-width="68px">
        <el-form-item label="专业类别">
          <el-cascader
              clearable
              v-model="classiFy"
              :options="expertTypes"
              :props="{ expandTrigger: 'hover', value: 'id',label: 'classifyName'}"
              @change="handleChange"></el-cascader>
        </el-form-item>
        <el-form-item label="在岗情况" prop="dutyStatus">
          <el-select v-model="queryParams.dutyStatus" placeholder="岗位状态" clearable>
            <el-option :key="0" label="在岗" :value="0"/>
            <el-option :key="1" label="退休" :value="1"/>
          </el-select>
        </el-form-item>
        <el-form-item label="时间范围" prop="searchTime">
          <el-date-picker
              v-model="searchTime"
              type="daterange"
              @change="changeTime"
              range-separator="至"
              start-placeholder="开始日期"
              end-placeholder="结束日期"
              value-format="YYYY-MM-DD"
          />
        </el-form-item>
        <el-form-item>
          <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
          <el-button icon="Refresh" @click="resetQuery">重置</el-button>
        </el-form-item>
      </el-form>
      <el-table v-loading="loading" :data="expertList" :border="true">
        <el-table-column type="index" width="55" align="center" />
        <el-table-column label="姓名" align="center" prop="name" />
        <el-table-column label="出生日期" align="center" prop="birthday" />
        <el-table-column label="学历" align="center" prop="degree" />
        <el-table-column label="职称" align="center" prop="title"/>
        <el-table-column label="专业" align="center" prop="speciality" />
        <el-table-column label="推荐类别组别" align="center">
          <template #default="scope">
            {{findNodeById(expertTypes,scope.row.bigClassify)}}/{{findNodeById(expertTypes,scope.row.smallClassify)}}
          </template>
        </el-table-column>
        <el-table-column label="联系电话" align="center" prop="phone"/>
        <el-table-column label="申请时间" align="center" prop="createTime">
          <template #default="scope">
            {{scope.row.createTime?scope.row.createTime.substring(0,10):''}}
          </template>
        </el-table-column>
        <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
          <template #default="scope">
            <el-button type="primary" link @click="openDialog('view',scope.row)">查看</el-button>
          </template>
        </el-table-column>
      </el-table>
      <pagination
          v-show="total > 0"
          :total="total"
          v-model:page="queryParams.pageNum"
          v-model:limit="queryParams.pageSize"
          @pagination="getList"
      />
      <expert-form ref="expertFormRef" @getList="getList"></expert-form>
    </div>
</template>

<script setup>
import {getCurrentInstance, onMounted, onUnmounted, reactive, ref, toRefs} from "vue";
import {ElMessage, ElMessageBox} from "element-plus";
import ExpertForm from "../applyRecords/components/expertForm";
import {delExpert, getExpertsList, getExpertTypes} from "../../../../api/form";
import { Plus } from '@element-plus/icons-vue'

const loading = ref(false);
const data = reactive({
  showSearch: true,
  total: 0,
  expertTypes: [],
  expertList: [],
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    state: 2,
    bigClassify: null,
    smallClassify: null,
    dutyStatus: null,
    params: {
      startTime: '',
      endTime: ''
    }
  },
  classiFy: [],
  searchTime: []
});

const { showSearch,total, expertTypes,expertList,queryParams,classiFy,searchTime} = toRefs(data);
const expertFormRef = ref()
onMounted(()=>{
  getList()
  getTypes()
})

onUnmounted(()=>{

})

const getTypes = async()=> {
  const res = await getExpertTypes()
  if(res.code == 200){
    data.expertTypes = res.data
  }else{
    ElMessage.warning(res.msg)
  }
}

const handleChange=(value)=> {
    if(!value){
        data.classiFy = []
        data.queryParams.bigClassify = ""
        data.queryParams.smallClassify = ""
    }
}
const changeTime=(value)=>{
  if(!value){
      data.queryParams.params.endTime = ""
      data.queryParams.params.startTime = ""
    }
}

const findNodeById = (data,value)=> {
  for (const node of data) {
    if (node.id === value) {
      return node.classifyName;
    }
    if (node.children) {
      const foundNode = findNodeById(node.children, value);
      if (foundNode) {
        return foundNode;
      }
    }
  }
  return null;
}

const handleQuery=()=> {
  data.queryParams.pageNum = 1
  if(data.classiFy && data.classiFy.length>0){
    data.queryParams.bigClassify = data.classiFy[0]
    data.queryParams.smallClassify = data.classiFy[1]
  }
  if(data.searchTime && data.searchTime.length>0){
    data.queryParams.params.startTime = data.searchTime[0]
    data.queryParams.params.endTime = data.searchTime[1]
  }
  getList()
}

const getList = async () => {
  loading.value = true;
  const res = await getExpertsList(data.queryParams)
  if(res.code == 200){
    data.expertList = res.data.list
    data.total = res.data.total
  }else{
    ElMessage.warning(res.msg)
  }
  loading.value = false;
}

const openDialog = (type, value) => {
  expertFormRef.value.openDialog(type, value);
}

const resetQuery=()=> {
  data.queryParams = {
    pageNum: 1,
    pageSize: 10,
    state: 2,
    bigClassify: null,
    smallClassify: null,
    dutyStatus: null,
    params: {
      startTime: '',
      endTime: ''
    }
  };
  data.classiFy = []
  data.searchTime = []
  handleQuery()
}

</script>
